# Copyright 2012 OpenStack Foundation.
# All Rights Reserved
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.
#

from tackerclient.tacker import v1_0 as cmd_base


class ListExt(cmd_base.ListCommand):
    """List all extensions."""

    resource = 'extension'
    list_columns = ['alias', 'name']


class ShowExt(cmd_base.ShowCommand):
    """Show information of a given resource."""

    resource = "extension"
    allow_names = False

    def get_id(self):
        return 'EXT-ALIAS'
